package com.gic.haoban.manage.service.service.role.impl;

import com.gic.commons.util.EntityUtil;
import com.gic.haoban.manage.service.dao.mapper.role.TabHaobanRoleMenuMapper;
import com.gic.haoban.manage.service.entity.role.TabHaobanRoleMenu;
import com.gic.haoban.manage.service.pojo.bo.role.HaobanRoleMenuBO;
import com.gic.haoban.manage.service.service.role.HaobanRoleMenuService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 好办小程序菜单(TabHaobanRoleMenu)表服务实现类
 *
 * @author mozhu
 * @since 2022-09-06 16:35:11
 */
@Service
public class HaobanRoleMenuServiceImpl implements HaobanRoleMenuService {

    @Autowired
    private TabHaobanRoleMenuMapper tabHaobanRoleMenuMapper;

    /**
     * 通过ID查询单条数据
     *
     * @param menuId 主键
     * @return 实例对象
     */
    @Override
    public TabHaobanRoleMenu queryById(Long menuId) {
        return this.tabHaobanRoleMenuMapper.queryById(menuId);
    }


    /**
     * 新增数据
     *
     * @param tabHaobanRoleMenu 实例对象
     * @return 实例对象
     */
    @Override
    public TabHaobanRoleMenu insert(TabHaobanRoleMenu tabHaobanRoleMenu) {
        tabHaobanRoleMenu.setCreateTime(new Date());
        tabHaobanRoleMenu.setUpdateTime(new Date());
        this.tabHaobanRoleMenuMapper.insert(tabHaobanRoleMenu);
        return tabHaobanRoleMenu;
    }

    /**
     * 修改数据
     *
     * @param tabHaobanRoleMenu 实例对象
     * @return 实例对象
     */
    @Override
    public TabHaobanRoleMenu update(TabHaobanRoleMenu tabHaobanRoleMenu) {
        tabHaobanRoleMenu.setUpdateTime(new Date());
        this.tabHaobanRoleMenuMapper.update(tabHaobanRoleMenu);
        return this.queryById(tabHaobanRoleMenu.getMenuId());
    }

    @Override
    public List<HaobanRoleMenuBO> getMenuTreeList() {
        List<TabHaobanRoleMenu> allMenuList = tabHaobanRoleMenuMapper.getAllMenuList();
        List<HaobanRoleMenuBO> menuBOList = EntityUtil.changeEntityListNew(HaobanRoleMenuBO.class, allMenuList);
        for (HaobanRoleMenuBO haobanRoleMenuBO : menuBOList) {
            List<HaobanRoleMenuBO> menus = iterateMenus(menuBOList, haobanRoleMenuBO.getMenuCode());
            haobanRoleMenuBO.setMenuBOList(menus);
        }
        return menuBOList;
    }


    public List<HaobanRoleMenuBO> iterateMenus(List<HaobanRoleMenuBO> menuVoList, String pCode) {
        List<HaobanRoleMenuBO> result = new ArrayList<>();
        for (HaobanRoleMenuBO haobanRoleMenuBO : menuVoList) {
            String menuCode = haobanRoleMenuBO.getMenuCode();
            String parentCode = haobanRoleMenuBO.getParentCode();
            if (StringUtils.isNotBlank(parentCode)) {
                if (parentCode.equals(pCode)) {
                    //递归查询当前子菜单的子菜单
                    List<HaobanRoleMenuBO> iterateMenu = iterateMenus(menuVoList, menuCode);
                    haobanRoleMenuBO.setMenuBOList(iterateMenu);
                    result.add(haobanRoleMenuBO);
                }
            }
        }
        return result;
    }

}
